@@ -238,13 +238,6 @@ YAZ_EXPORT int yaz_diag_srw_to_bib1(int srw_code);
 YAZ_EXPORT const char *yaz_srw_pack_to_str(int pack);
 YAZ_EXPORT int yaz_srw_str_to_pack(const char *str);
 
-/** \brief deprecated */
-YAZ_EXPORT char *yaz_uri_val(const char *path, const char *name, ODR o);
-
-/** \brief deprecated */
-YAZ_EXPORT void yaz_uri_val_int(const char *path, const char *name,
-                                ODR o, Odr_int **intp);
-
 YAZ_EXPORT int yaz_uri_to_array(const char *path, ODR o,
                                 char ***name, char ***val);
 YAZ_EXPORT void yaz_array_to_uri(char **path, ODR o,
@@ -328,6 +321,7 @@ void yaz_encode_sru_extra(Z_SRW_PDU *sr, ODR odr, const char *extra_args);
 #define YAZ_XMLNS_SRU_v1_0 "http://www.loc.gov/zing/srw/v1.0/"
 #define YAZ_XMLNS_SRU_v1_1 "http://www.loc.gov/zing/srw/"
 #define YAZ_XMLNS_DIAG_v1_1 "http://www.loc.gov/zing/srw/diagnostic/"
+#define YAZ_XMLNS_DIAG_v2 "http://docs.oasis-open.org/ns/search-ws/diagnostic"
 #define YAZ_XMLNS_UPDATE_v0_9 "http://www.loc.gov/zing/srw/update/"
 #define YAZ_XMLNS_SRU_v2_mask "http://docs.oasis-open.org/ns/search-ws/*"
 #define YAZ_XMLNS_SRU_v1_response "http://www.loc.gov/*"
